# Mouse Events with MochiKit

For a detailed description of what happens under the hood, check out mouse_events.js.

View Source: [ index.html | mouse_events.js | mouse_events.css ]

Hover, Click, or Scroll In Me:
Scroll Me and then the page scrolls!
Scroll Me and then the page scrolls!
Scroll Me and then the page scrolls!
Scroll Me and then the page scrolls!
Scroll Me and then the page scrolls!
Scroll Me and then the page scrolls!
Scroll Me and then the page scrolls!
Scroll Me and then the page scrolls!
Scroll Me and then the page scrolls!
Scroll Me and then the page scrolls!
Scroll Me and then the page scrolls!
Scroll Me and then the page scrolls!
Scroll Me and then the page scrolls!
Scroll Me and then the page scrolls!
Scroll Me and then the page scrolls!
Scroll Me and then the page scrolls!
Scroll Me and then the page scrolls!
Scroll Me and then the page scrolls!
Scroll Me and then the page scrolls!
Scroll Me and then the page scrolls!
Scroll Me and then the page does not scroll!
Scroll Me and then the page does not scroll!
Scroll Me and then the page does not scroll!
Scroll Me and then the page does not scroll!
Scroll Me and then the page does not scroll!
Scroll Me and then the page does not scroll!
Scroll Me and then the page does not scroll!
Scroll Me and then the page does not scroll!
Scroll Me and then the page does not scroll!
Scroll Me and then the page does not scroll!
Scroll Me and then the page does not scroll!
Scroll Me and then the page does not scroll!
Scroll Me and then the page does not scroll!
Scroll Me and then the page does not scroll!
Scroll Me and then the page does not scroll!
Scroll Me and then the page does not scroll!
Scroll Me and then the page does not scroll!
Scroll Me and then the page does not scroll!
Scroll Me and then the page does not scroll!
Scroll Me and then the page does not scroll!
Ignore me I just make the page big enough to require scrollbars.
Ignore me I just make the page big enough to require scrollbars.
Ignore me I just make the page big enough to require scrollbars.
Ignore me I just make the page big enough to require scrollbars.
Ignore me I just make the page big enough to require scrollbars.
Ignore me I just make the page big enough to require scrollbars.
Ignore me I just make the page big enough to require scrollbars.
Ignore me I just make the page big enough to require scrollbars.
Ignore me I just make the page big enough to require scrollbars.